==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_sk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Žiadne výsledky vyhľadávania</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Naozaj chcete odinštalovať %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdiť</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Odstrániť z plochy</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Odstrániť z panelu</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Odinštalovať</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Otvorené cez proxy</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Zakázať škálovanie zobrazenia</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Odoslať na plochu</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Odoslať na panel</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Odobrať zo štartu</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Pridať do štartu</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Všetky aplikácie</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Hra</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Kancelária</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Čítanie</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Vývoj</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Iné</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Naozaj chcete odinštalovať %1 ?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Všetky závislosti budú odstránené</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdiť</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videá</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stiahnuté</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zamknúť</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásiť</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zamknúť</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásiť</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videá</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stiahnuté</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stiahnuté</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručné</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videá</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Naozaj chcete odinštalovať %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdiť</translation>
    </message>
</context>
</TS>

==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_sk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Žiadne výsledky vyhľadávania</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Kancelária</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Čítanie</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Vývoj</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Hry</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostatné</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdiť</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Naozaj chcete odinštalovať %1 ?</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Odstrániť z plochy</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Odstrániť z panelu</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Odinštalovať</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Zakázať škálovanie zobrazenia</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Odoslať na plochu</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Odoslať na panel</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Odobrať zo štartu</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Pridať do štartu</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Všetky aplikácie</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Hra</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Kancelária</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Čítanie</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Vývoj</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Iné</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videá</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stiahnuté</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zamknúť</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásiť</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zamknúť</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásiť</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videá</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stiahnuté</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stiahnuté</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručné</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videá</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Napájanie</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Všetky kategórie</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdiť</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Naozaj chcete odinštalovať %1 ?</translation>
    </message>
</context>
</TS>
